@@ -2,4 +2,4 @@
 
 from threading import RLock
 
-RECURSIVE_THREAD_LOCK = RLock()
+RLOCK: RLock = RLock()
